@@ -4,7 +4,7 @@
 #
 
 package Parallel::WorkUnit;
-$Parallel::WorkUnit::VERSION = '1.110';
+$Parallel::WorkUnit::VERSION = '1.112';
 use v5.8;
 
 # ABSTRACT: Provide multi-paradigm forking with ability to pass back data
@@ -640,7 +640,7 @@ Parallel::WorkUnit - Provide multi-paradigm forking with ability to pass back da
 
 =head1 VERSION
 
-version 1.110
+version 1.112
 
 =head1 SYNOPSIS
 
@@ -743,7 +743,7 @@ for additional information.
 
   $wu->async( sub { return 1 }, \&callback );
 
-  # When using ordered return mode
+  # To get back results in "ordered" return mode
   $wu->async( sub { return 1 } );
   @results = $wu->waitall();
 
@@ -790,13 +790,12 @@ method will return.
 If a child dies unexpectedly, this method will C<die()> and propagate a
 modified exception.
 
-In the standard (not ordered) mode, I.E. where the C<ordered> attribute
-is set to false, this will return nothing.
+In the standard (not ordered) mode, I.E. where a callback was passed
+to C<async()>, this will return nothing.
 
-In the ordered mode, I.E. where the C<ordered> attribute is set to
-true, this will return the results of the async calls in an ordered
-list.  The list will be ordered by the order in which the async calls
-were executed.
+In the ordered mode, I.E. where no callbacks were provided to C<async()>,
+this will return the results of the async calls in an ordered list.  The
+list will be ordered by the order in which the async calls were executed.
 
 =head2 waitone()
 
